;; Generated package description from dtache.el  -*- no-byte-compile: t -*-
(define-package "dtache" "0.7" "A package to launch, and manage, dtache processes" '((emacs "27.1") (detached "0.7")) :commit "b194f96af4e6298fe086a844115ea23300be7166" :authors '(("Niklas Eklund" . "niklas.eklund@posteo.net")) :maintainer '("Niklas Eklund" . "niklas.eklund@posteo.net") :keywords '("convenience" "processes") :url "https://sr.ht/~niklaseklund/dtache.el/")
